@@ -3,10 +3,6 @@
 #include <stdlib.h> // for NULL
 #include <R_ext/Rdynload.h>
 
-/* FIXME:
-   Check these declarations against the C/Fortran source code.
-*/
-
 /* .Call calls */
 extern SEXP ar(SEXP, SEXP, SEXP);
 extern SEXP bar(SEXP, SEXP, SEXP);
@@ -21,9 +17,12 @@ extern SEXP pathdist_floyd(SEXP);
 extern SEXP reorder_dist(SEXP, SEXP);
 extern SEXP rgar(SEXP, SEXP, SEXP, SEXP);
 extern SEXP stress(SEXP, SEXP, SEXP, SEXP);
+extern void isMon(void *, void *, void *, void *);
+extern void permNext(void *, void *);
+
 
 /* .Fortran calls */
-extern void F77_NAME(arsa)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(arsa)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(bburcg)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(bbwrcg)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void F77_NAME(cbea)(void *, void *, void *, void *, void *, void *, void *);
@@ -47,6 +46,13 @@ static const R_CallMethodDef CallEntries[] = {
     {NULL, NULL, 0}
 };
 
+static const R_CMethodDef CEntries[] = {
+  {"isMon",        (DL_FUNC) &isMon,        4},
+  {"permNext",     (DL_FUNC) &permNext,     2},
+  {NULL, NULL, 0}
+};
+
+
 static const R_FortranMethodDef FortranEntries[] = {
     {"arsa",   (DL_FUNC) &F77_NAME(arsa),   15},
     {"bburcg", (DL_FUNC) &F77_NAME(bburcg), 10},
@@ -59,6 +65,6 @@ static const R_FortranMethodDef FortranEntries[] = {
 
 void R_init_seriation(DllInfo *dll)
 {
-    R_registerRoutines(dll, NULL, CallEntries, FortranEntries, NULL);
+    R_registerRoutines(dll, CEntries, CallEntries, FortranEntries, NULL);
     R_useDynamicSymbols(dll, FALSE);
 }
